#
# spec file for package gnome-pomodoro
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global __requires_exclude typelib\\(Meta\\)
Name:           gnome-pomodoro
Version:        0.20.0
Release:        bp154.1.175
Summary:        A time management utility for GNOME
License:        GPL-3.0-or-later
Group:          Productivity/Office/Other
URL:            https://gnomepomodoro.org
Source:         https://github.com/codito/%{name}/archive/%{version}.tar.gz
Source99:       gnome-pomodoro-rpmlintrc
BuildRequires:  desktop-file-utils
BuildRequires:  docbook-utils
BuildRequires:  gettext >= 0.19.6
BuildRequires:  gnome-common
BuildRequires:  gnome-shell < 42
BuildRequires:  gnome-shell >= 3.36.0
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  vala >= 0.28
BuildRequires:  pkgconfig(appstream-glib) >= 0.7.3
BuildRequires:  pkgconfig(gio-2.0) >= 2.38.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.38.0
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 0.10.1
BuildRequires:  pkgconfig(gom-1.0)
BuildRequires:  pkgconfig(gsettings-desktop-schemas) >= 3.16.0
BuildRequires:  pkgconfig(gstreamer-1.0) >= 1.0.10
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.20.0
BuildRequires:  pkgconfig(libcanberra) >= 0.30
BuildRequires:  pkgconfig(libpeas-1.0) >= 1.5.0
BuildRequires:  pkgconfig(sqlite3)
Requires:       gnome-shell < 42
Requires:       gnome-shell >= 3.36.0
Requires:       gstreamer
Requires:       gtk3 >= 3.20.0
Requires:       hicolor-icon-theme
Recommends:     gstreamer-plugins-base

%description
A GNOME utility that helps managing time according to Pomodoro Technique. It
intends to improve productivity and focus by taking short breaks after every
25 minutes of work.

%lang_package

%prep
%setup -q

%build
%meson
%meson_build

%install
%meson_install
find %{buildroot} -type f -name "*.la" -delete -print
desktop-file-edit %{buildroot}/%{_datadir}/applications/*.desktop \
    --set-key=X-AppInstall-Package --set-value=%{name}

%find_lang %{name}

%check
desktop-file-validate %{buildroot}/%{_datadir}/applications/org.gnome.Pomodoro.desktop

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%posttrans
gtk-update-icon-cache %{_datadir}/icons/hicolor &> /dev/null || :
glib-compile-schemas %{_datadir}/glib-2.0/schemas &> /dev/null || :

%files lang -f %{name}.lang

%files
%doc README.md NEWS
%license COPYING
%{_bindir}/gnome-pomodoro
%{_datadir}/metainfo/org.gnome.Pomodoro.appdata.xml
%{_datadir}/applications/org.gnome.Pomodoro.desktop
%{_datadir}/dbus-1/services/org.gnome.Pomodoro.service
%{_datadir}/glib-2.0/schemas/org.gnome.pomodoro.gschema.xml
%{_datadir}/glib-2.0/schemas/org.gnome.pomodoro.plugins.actions.gschema.xml
%{_datadir}/glib-2.0/schemas/org.gnome.pomodoro.plugins.gnome.gschema.xml
%{_datadir}/glib-2.0/schemas/org.gnome.pomodoro.plugins.sounds.gschema.xml
%{_datadir}/gnome-pomodoro/
%{_datadir}/gnome-shell/extensions/pomodoro@arun.codito.in
%{_datadir}/icons/hicolor/*/apps/*
#make it work for :42
%dir %{_datadir}/metainfo
%{_libdir}/gnome-pomodoro/
%{_libdir}/libgnome-pomodoro.so*

%changelog
* Thu Sep 30 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Set maximum gnome-shell version to 42, now that it supports 41.
* Sun Sep 26 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.20.0:
  * Support for GNOME Shell 41
* Mon Sep 20 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.19.2:
  * Fix dialog animation braking ScreenShield
  * Cleanup deprecated code
  * Fix blur effect artifacts
  * Dont wake up the screen after screensaver
  * Fix possible recursion during blinking animation
  * Workaround choppy blur effect animation in gnome-shell 3.38
  * Fix indicator opacity after lock screen
* Tue Apr 13 2021 Michael Vetter <mvetter@suse.com>
- Update to version 0.19.1:
  * Lower the cpu usage of the animation when on pause
* Wed Apr  7 2021 Michael Vetter <mvetter@suse.com>
- Update to version 0.19.0:
  * Support for GNOME Shell 40
  * Added support for meson
  * Changed blur effect during break
  * Updated translation
* Thu Oct  8 2020 Andrei Dziahel <develop7@develop7.info>
- get actually ready for gnome-shell 3.38
* Mon Oct  5 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.18.0:
  * Support for GNOME Shell 3.38
  * Removed ayatana-appindicator3 support
  * Added Norwegian translation
  * Added Finnish translation
  * Updated Indonesian translation
  * Updated Chinese translation
  * Updated Russian translation
  * Updated French translation
* Mon Jun 15 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Drop pkgconfig(ayatana-appindicator3-0.1) BuildRequires:
  ayatana-appindicator has ben failing to build for a while and is
  dying.
* Wed Apr 22 2020 Andrei Dziahel <develop7@develop7.info>
- Fix gnome shell version requirements since upstream supports
  single gnome-shell version only.
- Clean gnome-pomodoro.spec with spec-cleaner.
* Mon Mar 23 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.17.0:
  * Support for GNOME Shell 3.36
  * Updated Catalan translation (thanks @antoniofsm)
* Thu Jan 30 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Mon Oct  7 2019 mvetter@suse.com
- Update to 0.16.0:
  * Support for GNOME Shell 3.34
  * Added esperanto translation (thanks @SeZuo)
  * Moved app-menu to main window
* Mon Apr  8 2019 mvetter@suse.com
- Update to version 0.15.1:
  + Minor code cleanups to support ES6 syntax
  + Support for GNOME Shell 3.32
  + Fix for build with vala 0.44.1
  + Updated German translation
  + Fix for handle error recreating existing folder
  + Minor code cleanups
* Mon Dec  3 2018 bjorn.lie@gmail.com
- Update to version 0.14.0:
  + Support for GNOME Shell 3.28 and 3.30.
  + Stats.
  + Background blur under the dialog during breaks.
  + Updated translations.
- Replace pkgconfig(appindicator3-0.1) with
  pkgconfig(ayatana-appindicator3-0.1) BuildRequires following
  upstream changes.
- Add pkgconfig(gom-1.0) and pkgconfig(sqlite3) BuildRequires: New
  dependencies.
- Run spec-cleaner, modernize spec.
* Tue Dec  5 2017 dimstar@opensuse.org
- Require appstream-glib >= 0.7.3: This version changed the default
  location for the appdata file from /usr/share/appdata to
  /usr/share/mimeinfo. Since this package needs to be bootstrapped
  we need to know what we end up with.
* Tue Nov 21 2017 mvetter@suse.com
- Update to 0.13.4:
  + Add and update various translations.
  + Fix hiding notifications during pomodoro.
  + Update sound file in canberra cache.
  + Log timer entries in database.
  + Simple blur effect for the notification dialog.
  + Display screen notification timer only on primary monitor.
  + Display notifications despite timer being paused.
  + gnome: Use Shell D-Bus instead of gsettings.
  + Wait for plugins capabilities during startup.
  + Various bugfixes.
* Fri Sep 15 2017 mvetter@suse.com
- Update to 0.13.3:
  + Fix hiding notifications during pomodoro.
  + Update sound file in canberra cache.
  + Simplify Utils.Patch class.
  + Update and add translations.
  + Mark as compatible with GNOME 3.26.
- Remove fedora conditions
- Remove not needed macros like %%icon_theme_cache_postun
* Fri Mar 17 2017 mvetter@suse.com
- Update to 0.13.1
  + Support for GNOME Shell 3.24.
  + Bug fixes.
- Drop intltool in favor of newer gettext.
- Remove libgnome-desktop-3.0 dependency (happened in 0.13.0).
- Add BuildRequires appstream-glib for AppStream support.
- Add BuildRequires libappindicator to provide indicator on
  other desktops than GNOME.
* Mon Sep  5 2016 zaitor@opensuse.org
- Add global Requires exclude for the now private typelib(Meta)
  from mutter.
* Mon Jun 20 2016 mvetter@suse.com
- Update to version 0.12.1:
  + Fix for build error.
- Add gnome-pomodoro-rpmlintrc: lib is only used by pomodoro.
- BuildRequire pkgconfig(gio-2.0) instead of
  pkgconfig(dbus-glib-1): Migrated from libdubs-glib to GDBus.
- Drop BuildRequires/Recommends for:
  + telepathy-glib: Drop integration with Telepathy.
  + google-droid-sans-fonts: Don't use Droid Sans for timer digits,
    instead use default system font.
- Added BuildRequires:
  + gsettings-desktop-schemas: to provide fallback for other
    desktops.
  + pkgconfig(libpeas): added a plugin engine based on libpeas.
- Drop passing of prefix to autogen as it gets done in there
  automatically.
- Linker flags changed due to issues:
  gh#codito/gnome-pomodoro#159 and gh#codito/gnome-pomodoro#195.
* Mon Jun 13 2016 mvetter@suse.com
- Update to version 0.12.0:
  + Support for more desktops.
  + Ability to pause the timer.
  + Ability add plugins.
  + Code refactoring.
  + Bug fixes.
  + Dropped Telepathy and Skype integration.
  + Dropped support for GNOME Shell 3.14 and older.
* Wed May 18 2016 mvetter@suse.com
- Update to version 0.11.3:
  + Ignore small mouse movements in screen notification.
  + Fixed indicator not updating.
  + Cleaned up some compilation warnings.
* Mon Apr  4 2016 mvetter@suse.com
- Update to version 0.11.2:
  + Add GNOME 3.20 support.
* Fri Nov 13 2015 mvetter@suse.com
- Update to version 0.11.1:
  + Add GNOME 3.18 support.
  + Updated translations.
* Tue Jul 14 2015 mvetter@suse.com
- Correct glib2 macros
* Mon Jul 13 2015 mvetter@suse.com
- Using macros in post/postun
- Splitting in lang package
- Use proper configure
* Thu Jul  2 2015 mvetter@suse.com
- Remove deb file
- Clean up spec file
- Correct name of spec file and add changes file
- Package got created originally by Kamil Prusko (kamilprusko)
